## 1.1.0.20260408 (2026-04-08)

Use dashes instead of underscores for METADATA.toml field names ([#15614](https://github.com/python/typeshed/pull/15614))

## 1.1.0.20251220 (2025-12-20)

[PyMySQL] Add Cursor.warning_count attribute ([#15150](https://github.com/python/typeshed/pull/15150))

## 1.1.0.20250916 (2025-09-16)

[PyMySQL] Fix stubs for `pymysql.connections.Connection.__init__` ([#14724](https://github.com/python/typeshed/pull/14724))

## 1.1.0.20250914 (2025-09-14)

Update mypy to 1.18.1 ([#14699](https://github.com/python/typeshed/pull/14699))

## 1.1.0.20250909 (2025-09-09)

[PyMySQL] Add stub for `SSCursor.read_next` ([#14670](https://github.com/python/typeshed/pull/14670))

[PyMySQL] Improve `Connection.__init__` overloads & add missing types ([#14684](https://github.com/python/typeshed/pull/14684))

## 1.1.0.20250822 (2025-08-22)

Add __slots__ to third-party packages using stubdefaulter ([#14619](https://github.com/python/typeshed/pull/14619))

## 1.1.0.20250711 (2025-07-11)

[PyMySQL] Fix issue with import constants attributes ([#14393](https://github.com/python/typeshed/pull/14393))

## 1.1.0.20250708 (2025-07-08)

[PyMySQL] Add missing stubs ([#14335](https://github.com/python/typeshed/pull/14335))

## 1.1.0.20250516 (2025-05-16)

Replace `Incomplete | None = None` in third party stubs ([#14063](https://github.com/python/typeshed/pull/14063))

## 1.1.0.20241103 (2024-11-03)

Improve pymysql stubs ([#12942](https://github.com/python/typeshed/pull/12942))

Co-authored-by: Shamil <ashm.tech@proton.me>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 1.1.0.20240524 (2024-05-24)

Update PyMySQL to 1.1.1 ([#12001](https://github.com/python/typeshed/pull/12001))

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 1.1.0.20240425 (2024-04-25)

Bump pyright to v1.1.360 ([#11810](https://github.com/python/typeshed/pull/11810))

## 1.1.0.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml ([#10487](https://github.com/python/typeshed/pull/10487))

Closes: #10478

## 1.1.0.0 (2023-06-28)

Bump PyMySQL to `1.1.*` ([#10376](https://github.com/python/typeshed/pull/10376))

## 1.0.19.7 (2023-05-10)

Add `partial_stub` metadata field ([#10157](https://github.com/python/typeshed/pull/10157))

## 1.0.19.6 (2023-03-27)

Add default values for third-party stubs beginning with 'P' ([#9957](https://github.com/python/typeshed/pull/9957))

## 1.0.19.5 (2023-02-22)

Update `Unused` parameters in `stubs/` ([#9704](https://github.com/python/typeshed/pull/9704))

* Update _Unused TypeAlias

* Update `object | None` params

* Replace unused `object` parameters with `Unused` alias

## 1.0.19.4 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` ([#9779](https://github.com/python/typeshed/pull/9779))

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.0.19.3 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` ([#9702](https://github.com/python/typeshed/pull/9702))

## 1.0.19.2 (2023-01-18)

Replace `Any` with `Incomplete` in many places ([#9558](https://github.com/python/typeshed/pull/9558))

## 1.0.19.1 (2022-10-16)

Remove empty `__init__` methods from classes with 0 parents ([#8907](https://github.com/python/typeshed/pull/8907))

## 1.0.19 (2022-04-29)

Delete python 2 branches from third-party stubs ([#7741](https://github.com/python/typeshed/pull/7741))

Since #7703, we no longer have third-party stubs that support Python 2, so code like `if sys.version_info >= (3, 0)` can be simplified.

## 1.0.18 (2022-04-21)

Update PyMySQL constants ([#7670](https://github.com/python/typeshed/pull/7670))

## 1.0.17 (2022-04-16)

Python 3 stubs: use `str` instead of `typing.Text` ([#7638](https://github.com/python/typeshed/pull/7638))

Third-party stubs: import from `collections.abc` where possible ([#7637](https://github.com/python/typeshed/pull/7637))

## 1.0.16 (2022-04-16)

Use `TypeAlias` where possible for type aliases ([#7630](https://github.com/python/typeshed/pull/7630))

## 1.0.15 (2022-04-01)

Third-party stubs: Improve several `__exit__` methods ([#7575](https://github.com/python/typeshed/pull/7575))

## 1.0.14 (2022-03-16)

Use PEP 604 syntax wherever possible ([#7493](https://github.com/python/typeshed/pull/7493))

## 1.0.13 (2022-01-28)

Add __enter__/__exit__ to pymysql.Connection ([#7069](https://github.com/python/typeshed/pull/7069))

## 1.0.11 (2022-01-10)

Always use `_typeshed.Self`, where applicable ([#6880](https://github.com/python/typeshed/pull/6880))

* Always use `_typeshed.Self`, where applicable

* Revert changes to `google-cloud-ndb` (ambiguous)

* Remove empty line added by script

* Revert changes to `stubs/python-dateutil/dateutil/relativedelta.pyi`

* Manually add a few more that the script missed

* Improve `filelock` annotation

Source code here: https://github.com/tox-dev/py-filelock/blob/79ec7b2826e33b982fe83b057f359448b9d966ba/src/filelock/_api.py#L207

* Improve `opentracing/scope` annotation

Source code here: https://github.com/opentracing/opentracing-python/blob/3e1d357a348269ef54d67f761302fab93dbfc0f7/opentracing/scope.py#L71

* Improve `redis/client` stub

Source code here: https://github.com/redis/redis-py/blob/15f315a496c3267c8cbcc6d6d9c6005ea4d4a4d5/redis/client.py#L1217

* Improve `redis/lock` annotation

Source code here: https://github.com/redis/redis-py/blob/15f315a496c3267c8cbcc6d6d9c6005ea4d4a4d5/redis/lock.py#L155

* Improve `requests/models` annotation

Source code here: https://github.com/psf/requests/blob/d718e753834b84018014a23d663369ac27d1ab9c/requests/models.py#L653

## 1.0.10 (2022-01-08)

Use lowercase `type` everywhere ([#6853](https://github.com/python/typeshed/pull/6853))

## 1.0.8 (2021-12-28)

Use PEP 585 syntax wherever possible ([#6717](https://github.com/python/typeshed/pull/6717))

## 1.0.7 (2021-12-17)

Use stubtest 0.920 ([#6589](https://github.com/python/typeshed/pull/6589))

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>
Co-authored-by: Sebastian Rittau <srittau@rittau.biz>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 1.0.6 (2021-11-26)

Add mypy error codes to '# type: ignore' comments ([#6379](https://github.com/python/typeshed/pull/6379))

## 1.0.5 (2021-11-09)

Improve pymysql.converters stubs ([#6267](https://github.com/python/typeshed/pull/6267))

I spent far too much time being confused about why pyanalyze thought `pymysql.converters.escape_dict` only takes two arguments.

I rewrote the stubs from scratch using the implementation: https://github.com/PyMySQL/PyMySQL/blob/main/pymysql/converters.py.

The "charset" argument is ignored as far as I can tell; it gets passed to other functions but no function actually uses it.

Co-authored-by: Sebastian Rittau <srittau@rittau.biz>

## 1.0.4 (2021-10-15)

Use lowercase tuple where possible ([#6170](https://github.com/python/typeshed/pull/6170))

## 1.0.3 (2021-10-12)

Add star to all non-0.1 versions ([#6146](https://github.com/python/typeshed/pull/6146))

